==> tepez-static-website-0.4.0.tgz: package/gulp/util/metalsmith.js <==
﻿'use strict';
const Metalsmith = require('metalsmith');
const Path = require('path');
const GulpUtil = require('gulp-util');
const Joi = require('joi');
const _ = require('lodash');

const MetalsmithMrakdownit = require('metalsmith-markdownit');
const MetalsmithDrafts = require('metalsmith-drafts');
const MetalsmithCollections = require('metalsmith-collections');
const MetalsmithInPlace = require('metalsmith-in-place');
const MetalsmithPaths = require('metalsmith-paths');
const MetalsmithLayouts = require('metalsmith-layouts');
const MetalsmithRename = require('metalsmith-rename');
const MetalsmithSitemap = require('metalsmith-sitemap');
const MetalsmithPermalinks = require('metalsmith-permalinks');
const MetalsmithFilemetadata = require('metalsmith-filemetadata');
const MetalsmithIgnore = require('metalsmith-ignore');

const MarkdownItUtils = require('./markdownIt');
const TasksUtils = require('../util/utils');
const MetalsmithConfig = TasksUtils.metalsmithConfig;


const Jade = require('jade');
Jade.filters.md = Jade.filters.markdown = MarkdownItUtils.jstransformer;
require('metalsmith-in-place/node_modules/consolidate').requires.jade = Jade;
require('metalsmith-layouts/node_modules/consolidate').requires.jade = Jade;

const mdPlugin = MetalsmithMrakdownit('default', {
  html: true
});
MarkdownItUtils.initParser(mdPlugin.parser);


exports = module.exports = {};

exports.build = function (metadata) {

  return Metalsmith(MetalsmithConfig.srcDir)
    .clean(false)// otherwise, we'll delete the outputs of other tasks
    .metadata(_.assign({
      href: (path) => {
        if (_.isString(path)) {
          return `${metadata.baseUrl}/${path}`;
        }
        if (path.name === 'index') {
          return `${metadata.baseUrl}/${path.dir}`;
        }
        return `${metadata.baseUrl}/${path.dir}/${path.name}`;
      }
    }, metadata))

    .use(MetalsmithDrafts())
    .use(MetalsmithIgnore(MetalsmithConfig.ignore))

    .use(MetalsmithPaths())
    .use(MetalsmithCollections(MetalsmithConfig.collections))
    .use(MetalsmithInPlace({
      engine: 'lodash',
      pattern: '**/*.md'
    }))
    .use(mdPlugin)
    // Add absolute filename attribute to every file so we can use relative extends in jade
    // We don't use metalsmith-filenames because it set a path relative to the src dir
    .use((files, metalsmith) => {
      Object.keys(files).forEach(function (filename) {
        if (!files[filename].filename) {
          files[filename].filename = metalsmith.path(Path.join(metalsmith.source(), filename));
        }
      });
    })

    .use((files, metalsmith) => {
      // For each page we want to use disqus on, we'll have a unique disqusPageId
      // so we can move the pages and we won't lose the conversations
      // Check for duplicates disqusPageId
      _(files)
        .filter('disqusPageId')
        .groupBy('disqusPageId')
        .forEach((pagesWithId, disqusPageId) => {
          if (pagesWithId.length > 1) {
            GulpUtil.log(`disqusPageId ${GulpUtil.colors.yellow(disqusPageId)} appears in multiple files: ${GulpUtil.colors.cyan(_.map(pagesWithId, 'filename').join(', '))}`);
          }
        });

      const collectionNames =_.keys(MetalsmithConfig.collections);
      const fileSchema = Joi.object().keys({
        priority: Joi.number().min(0).max(1),
        description: Joi.string(),
        keywords: Joi.string(),
        'private': Joi.boolean(),
        changefreq: Joi.string().valid('always', 'hourly', 'daily', 'weekly', 'monthly', 'yearly', 'never'),
        title: Joi.string(),
        layout: Joi.string(),
        collection: Joi.array().optional().items(Joi.string().valid(collectionNames)).min(0).max(1),
        childrenCollection: Joi.string().valid(collectionNames),
        position: Joi.number().integer(),
        disqusPageId: Joi.string().regex(/^[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i),
        contents: Joi.any(),
        filename: Joi.string().required(),

        mode: Joi.any(),
        stats: Joi.object(),
        path: Joi.any(),
        previous: Joi.any(),
        next: Joi.any()
      }).unknown(true);

      _.forEach(files, (file) => {
        Joi.validate(file, fileSchema, (err) => {
          if (err) {
            GulpUtil.log(`page ${GulpUtil.colors.cyan(file.filename)} has invalid meta data: ${err}`);
            GulpUtil.log(file);
          }
        });
      });
    })

    .use(MetalsmithInPlace({
      engine: 'jade',
      pattern: '**/*.jade'
    }))
    .use(MetalsmithLayouts({
      engine: 'jade',
      directory: 'layouts' // (this is the default)
    }))
    .use(MetalsmithRename([[/\.jade$/, '.html']]))
    .use(MetalsmithPermalinks({
      relative: false
    }))
    .use(MetalsmithFilemetadata(MetalsmithConfig.filemetadata))
    .use(MetalsmithSitemap(MetalsmithConfig.sitemap));
};

==> tepez-static-website-0.7.2.tgz: package/gulp/util/metalsmith.js <==
﻿'use strict';
const Metalsmith = require('metalsmith');
const Path = require('path');
const GulpUtil = require('gulp-util');
const Joi = require('joi');
const _ = require('lodash');

const MetalsmithMrakdownit = require('metalsmith-markdownit');
const MetalsmithDrafts = require('metalsmith-drafts');
const MetalsmithCollections = require('metalsmith-collections');
const MetalsmithInPlace = require('metalsmith-in-place');
const MetalsmithPaths = require('metalsmith-paths');
const MetalsmithLayouts = require('metalsmith-layouts');
const MetalsmithRename = require('metalsmith-rename');
const MetalsmithSitemap = require('metalsmith-sitemap');
const MetalsmithPermalinks = require('metalsmith-permalinks');
const MetalsmithFilemetadata = require('metalsmith-filemetadata');
const MetalsmithIgnore = require('metalsmith-ignore');
const HighlighJs = require('highlight.js');

const MarkdownItUtils = require('./markdownIt');
const TasksUtils = require('../util/utils');
const MetalsmithConfig = TasksUtils.metalsmithConfig;

const Jade = require('jade');
// Note: this requires npm >= 3, otherwise consolidate will be under metalsmith-in-place / metalsmith-layouts
const Consolidate = require('consolidate');


exports = module.exports = {};

exports.build = function (metadata) {
  const beforeMdFilter = Jade.filters.md;
  const beforeMarkdownFilter = Jade.filters.markdown;
  const beforeConsolidateJade = Consolidate.requires.jade;

  const markdownOptions = {
    html: true,
    highlight: (str, lang) => {
      // Based on https://github.com/markdown-it/markdown-it#syntax-highlighting
      // with a difference that we don't swallow the HighlighJs error and we use lodash for escaping
      // since we don't have access to a markdown-it parser instance here
      if (lang && HighlighJs.getLanguage(lang)) {
        const highlighthedHtml = HighlighJs.highlight(lang, str, true).value;
        return `<pre class="hljs"><code class="language-${lang}">${highlighthedHtml}</code></pre>`
      }
      return `<pre class="hljs"><code>${_.escape(str)}</code></pre>`;
    }
  };

  // A markdown filter for Jade that first compiles the markdown with Lodash templates
  // on the metadata of the metalsmith instance
  const mdFilterWithLodashTemplate = (str, options) => {
    const afterLodash = _.template(str)(metalsmith._metadata);
    // Use the same options as we use for the markdown files we compile directly
    return MarkdownItUtils.jstransformer(afterLodash, markdownOptions)
  }

  Jade.filters.md = mdFilterWithLodashTemplate;
  Jade.filters.markdown = mdFilterWithLodashTemplate;
  Consolidate.requires.jade = Jade;

  const mdPlugin = MetalsmithMrakdownit('default', markdownOptions);
  MarkdownItUtils.initParser(mdPlugin.parser);

  const metalsmith = Metalsmith(MetalsmithConfig.srcDir)
    .clean(false)// otherwise, we'll delete the outputs of other tasks
    .metadata(_.assign({
      href: (path) => {
        if (_.isString(path)) {
          return `${metadata.baseUrl}/${path}`;
        }
        if (path.name === 'index') {
          return `${metadata.baseUrl}/${path.dir}`;
        }
        return `${metadata.baseUrl}/${path.dir}/${path.name}`;
      }
    }, metadata))

    .use(MetalsmithDrafts())
    .use(MetalsmithIgnore(MetalsmithConfig.ignore))

    .use(MetalsmithPaths())
    .use(MetalsmithCollections(MetalsmithConfig.collections))
    .use(MetalsmithInPlace({
      engine: 'lodash',
      pattern: '**/*.md'
    }))
    .use(mdPlugin)
    // Add absolute filename attribute to every file so we can use relative extends in jade
    // We don't use metalsmith-filenames because it set a path relative to the src dir
    .use((files, metalsmith) => {
      Object.keys(files).forEach(function (filename) {
        if (!files[filename].filename) {
          files[filename].filename = metalsmith.path(Path.join(metalsmith.source(), filename));
        }
      });
    })

    .use((files, metalsmith) => {
      // For each page we want to use disqus on, we'll have a unique disqusPageId
      // so we can move the pages and we won't lose the conversations
      // Check for duplicates disqusPageId
      _(files)
        .filter('disqusPageId')
        .groupBy('disqusPageId')
        .forEach((pagesWithId, disqusPageId) => {
          if (pagesWithId.length > 1) {
            GulpUtil.log(`disqusPageId ${GulpUtil.colors.yellow(disqusPageId)} appears in multiple files: ${GulpUtil.colors.cyan(_.map(pagesWithId, 'filename').join(', '))}`);
          }
        });

      const collectionNames =_.keys(MetalsmithConfig.collections);
      const fileSchema = Joi.object().keys({
        priority: Joi.number().min(0).max(1),
        description: Joi.string(),
        keywords: Joi.string(),
        'private': Joi.boolean(),
        changefreq: Joi.string().valid('always', 'hourly', 'daily', 'weekly', 'monthly', 'yearly', 'never'),
        title: Joi.string(),
        layout: Joi.string(),
        collection: Joi.array().optional().items(Joi.string().valid(collectionNames)).min(0).max(1),
        childrenCollection: Joi.string().valid(collectionNames),
        position: Joi.number().integer(),
        disqusPageId: Joi.string().regex(/^[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i),
        contents: Joi.any(),
        filename: Joi.string().required(),

        mode: Joi.any(),
        stats: Joi.object(),
        path: Joi.any(),
        previous: Joi.any(),
        next: Joi.any()
      }).unknown(true);

      _.forEach(files, (file) => {
        Joi.validate(file, fileSchema, (err) => {
          if (err) {
            GulpUtil.log(`page ${GulpUtil.colors.cyan(file.filename)} has invalid meta data: ${err}`);
            GulpUtil.log(file);
          }
        });
      });
    })

    .use(MetalsmithInPlace({
      engine: 'jade',
      pattern: '**/*.jade'
    }))
    .use(MetalsmithLayouts({
      engine: 'jade',
      directory: 'layouts' // (this is the default)
    }))
    .use(MetalsmithRename([[/\.jade$/, '.html']]))
    .use(MetalsmithPermalinks({
      relative: false
    }))
    .use(MetalsmithFilemetadata(MetalsmithConfig.filemetadata))
    .use(MetalsmithSitemap(MetalsmithConfig.sitemap))
    .use((files, metalsmith, done) => {
      Jade.filters.md = beforeMdFilter;
      Jade.filters.markdown = beforeMarkdownFilter;
      Consolidate.requires.jade = beforeConsolidateJade;
      done();
    });

  return metalsmith;
};
